@@ -14,7 +14,7 @@ use Data::Table::Text qw(:all);
 use File::Copy;
 use POSIX qw(strftime);                                                         # http://www.cplusplus.com/reference/ctime/strftime/
 
-our $VERSION = '2017.4444';
+our $VERSION = '2017.505';
 
 #-------------------------------------------------------------------------------
 # Constants
@@ -153,7 +153,6 @@ sub pushIcon                                                    # Create and tra
       my $c = "convert -strip $icon -resize ${s}x${s}! $appIcon";
       my $r = xxx($c);
       !$r or confess "Unable to create icon:\n$r\n";
-
       my $res = $android->appResFolder;
       my $T = $res.$d.'-'.$dir.'dpi/'.$i.'.png';
       makePath($T);
@@ -311,7 +310,6 @@ sub create
 
 sub make
  {my ($android) = @_;
-
   my $appName    = $android->appName;
 
   my $sdk        = $android->sdk;
@@ -440,8 +438,10 @@ sub make
     my $z = xxx("$zipAlign -f 4 $apj $apk");
     $android->logMessage($z);
 
+    my $alg = $android->debug ? '' : "-sigalg SHA1withRSA -digestalg SHA1";
+
     my $s = xxx("echo $keyStorePwd |",                                          # Sign
-                "jarsigner -verbose -keystore $keyStoreFile $apk $keyAlias");
+     "jarsigner -verbose $alg -keystore $keyStoreFile $apk $keyAlias");
 
     $s =~ /reference a valid KeyStore key entry containing a private key/s and
       confess "Invalid keystore password: $keyStorePwd ".
